@@ -36,6 +36,7 @@ from sqlalchemy.testing import AssertsCompiledSQL
 from sqlalchemy.testing import eq_
 from sqlalchemy.testing import fixtures
 from sqlalchemy.testing import is_
+from sqlalchemy.testing.assertions import eq_ignore_whitespace
 
 tbl = table("t", column("a"))
 
@@ -137,7 +138,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
     def test_update(self):
         t = table("sometable", column("somecolumn"))
         self.assert_compile(
-            t.update(t.c.somecolumn == 7),
+            t.update().where(t.c.somecolumn == 7),
             "UPDATE sometable SET somecolumn=:somecolum"
             "n WHERE sometable.somecolumn = "
             ":somecolumn_1",
@@ -703,7 +704,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             schema="paj",
         )
         self.assert_compile(
-            tbl.delete(tbl.c.id == 1),
+            tbl.delete().where(tbl.c.id == 1),
             "DELETE FROM paj.test WHERE paj.test.id = " ":id_1",
         )
         s = select(tbl.c.id).where(tbl.c.id == 1)
@@ -723,7 +724,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             schema="banana.paj",
         )
         self.assert_compile(
-            tbl.delete(tbl.c.id == 1),
+            tbl.delete().where(tbl.c.id == 1),
             "DELETE FROM banana.paj.test WHERE " "banana.paj.test.id = :id_1",
         )
         s = select(tbl.c.id).where(tbl.c.id == 1)
@@ -744,7 +745,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             schema="banana split.paj",
         )
         self.assert_compile(
-            tbl.delete(tbl.c.id == 1),
+            tbl.delete().where(tbl.c.id == 1),
             "DELETE FROM [banana split].paj.test WHERE "
             "[banana split].paj.test.id = :id_1",
         )
@@ -767,7 +768,7 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             schema="banana split.paj with a space",
         )
         self.assert_compile(
-            tbl.delete(tbl.c.id == 1),
+            tbl.delete().where(tbl.c.id == 1),
             "DELETE FROM [banana split].[paj with a "
             "space].test WHERE [banana split].[paj "
             "with a space].test.id = :id_1",
@@ -864,15 +865,17 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             column("name", String(128)),
             column("description", String(128)),
         )
-        u = update(table1, values=dict(name="foo")).returning(
-            table1.c.myid, table1.c.name
+        u = (
+            update(table1)
+            .values(dict(name="foo"))
+            .returning(table1.c.myid, table1.c.name)
         )
         self.assert_compile(
             u,
             "UPDATE mytable SET name=:name OUTPUT "
             "inserted.myid, inserted.name",
         )
-        u = update(table1, values=dict(name="foo")).returning(table1)
+        u = update(table1).values(dict(name="foo")).returning(table1)
         self.assert_compile(
             u,
             "UPDATE mytable SET name=:name OUTPUT "
@@ -880,7 +883,8 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             "inserted.description",
         )
         u = (
-            update(table1, values=dict(name="foo"))
+            update(table1)
+            .values(dict(name="foo"))
             .returning(table1)
             .where(table1.c.name == "bar")
         )
@@ -891,8 +895,10 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             "inserted.description WHERE mytable.name = "
             ":name_1",
         )
-        u = update(table1, values=dict(name="foo")).returning(
-            func.length(table1.c.name)
+        u = (
+            update(table1)
+            .values(dict(name="foo"))
+            .returning(func.length(table1.c.name))
         )
         self.assert_compile(
             u,
@@ -929,8 +935,10 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             column("name", String(128)),
             column("description", String(128)),
         )
-        i = insert(table1, values=dict(name="foo")).returning(
-            table1.c.myid, table1.c.name
+        i = (
+            insert(table1)
+            .values(dict(name="foo"))
+            .returning(table1.c.myid, table1.c.name)
         )
         self.assert_compile(
             i,
@@ -938,15 +946,17 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             "inserted.myid, inserted.name VALUES "
             "(:name)",
         )
-        i = insert(table1, values=dict(name="foo")).returning(table1)
+        i = insert(table1).values(dict(name="foo")).returning(table1)
         self.assert_compile(
             i,
             "INSERT INTO mytable (name) OUTPUT "
             "inserted.myid, inserted.name, "
             "inserted.description VALUES (:name)",
         )
-        i = insert(table1, values=dict(name="foo")).returning(
-            func.length(table1.c.name)
+        i = (
+            insert(table1)
+            .values(dict(name="foo"))
+            .returning(func.length(table1.c.name))
         )
         self.assert_compile(
             i,
@@ -967,6 +977,22 @@ class CompileTest(fixtures.TestBase, AssertsCompiledSQL):
             checkparams={"x_1": 5, "param_1": 10},
         )
 
+    def test_limit_using_top_literal_binds(self):
+        """test #6863"""
+        t = table("t", column("x", Integer), column("y", Integer))
+
+        s = select(t).where(t.c.x == 5).order_by(t.c.y).limit(10)
+
+        eq_ignore_whitespace(
+            str(
+                s.compile(
+                    dialect=mssql.dialect(),
+                    compile_kwargs={"literal_binds": True},
+                )
+            ),
+            "SELECT TOP 10 t.x, t.y FROM t WHERE t.x = 5 ORDER BY t.y",
+        )
+
     def test_limit_zero_using_top(self):
         t = table("t", column("x", Integer), column("y", Integer))
 
